# Code of Conduct

This project follows the [Contributor Covenant Code of Conduct v2.1](https://www.contributor-covenant.org/version/2/1/code_of_conduct/).

## Reporting

Report issues to the project maintainers via [GitHub Security Advisories](https://github.com/solentlabs/har-capture/security/advisories/new).

## Enforcement

Project maintainers are responsible for clarifying standards and taking appropriate action in response to unacceptable behavior.
